@@ -1,4 +1,4 @@
-from typing import List
+from typing import List, Optional
 
 from tea_client.models import TeaClientModel
 
@@ -46,6 +46,38 @@ class Task(TeaClientModel):
     description: str
 
 
+class TaskCreateRequest(TeaClientModel):
+    """Task object.
+
+    Attributes:
+        name (str): Task name.
+        description (str): Task description.
+        area (str, optional): Task area ID.
+        parent_task (str, optional): ID of the parent task.
+    """
+
+    name: str
+    description: str = ""
+    area: Optional[str] = None
+    parent_task: Optional[str] = None
+
+
+class TaskUpdateRequest(TeaClientModel):
+    """Evaluation table row object.
+
+    Attributes:
+        name (str, optional): Task name.
+        description (str, optional): Task description.
+        area (str, optional): Task area ID.
+        parent_task (str, optional): ID of the parent task.
+    """
+
+    name: Optional[str] = None
+    description: Optional[str] = None
+    area: Optional[str] = None
+    parent_task: Optional[str] = None
+
+
 class Tasks(Page):
     """Object representing a paginated page of tasks.
 
